[Cmake-commits] CMake branch, master, updated. v3.5.2-519-ga2de7f3

2016-04-27 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  a2de7f372c837b2744b8d722fc706a1e1bb6e015 (commit)
  from  edf1c8e37d96b6a657d83425b8a3977ff1fa54f5 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a2de7f372c837b2744b8d722fc706a1e1bb6e015
commit a2de7f372c837b2744b8d722fc706a1e1bb6e015
Author: Kitware Robot 
AuthorDate: Thu Apr 28 00:01:07 2016 -0400
Commit: Kitware Robot 
CommitDate: Thu Apr 28 00:01:07 2016 -0400

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index 28ec80e..489dc3c 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 5)
-set(CMake_VERSION_PATCH 20160427)
+set(CMake_VERSION_PATCH 20160428)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.5.2-1110-g3483677

2016-04-27 Thread Gregor Jasny via Cmake-commits
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  3483677c2681eb5627e7bfdffdaa0e3402fd2cca (commit)
   via  2d7d33ecb3efc5446c25d3ecb9327cd3fa2bae28 (commit)
  from  b3f751575385969e808fdaf45de09958822d5b1a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3483677c2681eb5627e7bfdffdaa0e3402fd2cca
commit 3483677c2681eb5627e7bfdffdaa0e3402fd2cca
Merge: b3f7515 2d7d33e
Author: Gregor Jasny 
AuthorDate: Wed Apr 27 16:40:04 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 16:40:04 2016 -0400

Merge topic 'hyperlink-documentation' into next

2d7d33ec Help: Hyperlink properties


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=2d7d33ecb3efc5446c25d3ecb9327cd3fa2bae28
commit 2d7d33ecb3efc5446c25d3ecb9327cd3fa2bae28
Author: Gregor Jasny 
AuthorDate: Wed Apr 27 22:38:59 2016 +0200
Commit: Gregor Jasny 
CommitDate: Wed Apr 27 22:38:59 2016 +0200

Help: Hyperlink properties

diff --git a/Help/prop_dir/LISTFILE_STACK.rst b/Help/prop_dir/LISTFILE_STACK.rst
index f729c1e..22ec4b6 100644
--- a/Help/prop_dir/LISTFILE_STACK.rst
+++ b/Help/prop_dir/LISTFILE_STACK.rst
@@ -5,5 +5,6 @@ The current stack of listfiles being processed.
 
 This property is mainly useful when trying to debug errors in your
 CMake scripts.  It returns a list of what list files are currently
-being processed, in order.  So if one listfile does an INCLUDE command
-then that is effectively pushing the included listfile onto the stack.
+being processed, in order.  So if one listfile does an
+:command:`include` command then that is effectively pushing the
+included listfile onto the stack.
diff --git a/Help/prop_gbl/FIND_LIBRARY_USE_LIB64_PATHS.rst 
b/Help/prop_gbl/FIND_LIBRARY_USE_LIB64_PATHS.rst
index 185246c..e52f8eb 100644
--- a/Help/prop_gbl/FIND_LIBRARY_USE_LIB64_PATHS.rst
+++ b/Help/prop_gbl/FIND_LIBRARY_USE_LIB64_PATHS.rst
@@ -1,9 +1,10 @@
 FIND_LIBRARY_USE_LIB64_PATHS
 
 
-Whether FIND_LIBRARY should automatically search lib64 directories.
+Whether :command:`find_library` should automatically search lib64
+directories.
 
 FIND_LIBRARY_USE_LIB64_PATHS is a boolean specifying whether the
-FIND_LIBRARY command should automatically search the lib64 variant of
-directories called lib in the search path when building 64-bit
-binaries.
+:command:`find_library` command should automatically search the lib64
+variant of directories called lib in the search path when building
+64-bit binaries.
diff --git a/Help/prop_gbl/FIND_LIBRARY_USE_OPENBSD_VERSIONING.rst 
b/Help/prop_gbl/FIND_LIBRARY_USE_OPENBSD_VERSIONING.rst
index 9a3edd8..beb94ac 100644
--- a/Help/prop_gbl/FIND_LIBRARY_USE_OPENBSD_VERSIONING.rst
+++ b/Help/prop_gbl/FIND_LIBRARY_USE_OPENBSD_VERSIONING.rst
@@ -1,9 +1,10 @@
 FIND_LIBRARY_USE_OPENBSD_VERSIONING
 ---
 
-Whether FIND_LIBRARY should find OpenBSD-style shared libraries.
+Whether :command:`find_library` should find OpenBSD-style shared
+libraries.
 
-This property is a boolean specifying whether the FIND_LIBRARY command
-should find shared libraries with OpenBSD-style versioned extension:
-".so..".  The property is set to true on OpenBSD and
-false on other platforms.
+This property is a boolean specifying whether the
+:command:`find_library` command should find shared libraries with
+OpenBSD-style versioned extension: ".so..".  The
+property is set to true on OpenBSD and false on other platforms.
diff --git a/Help/prop_gbl/IN_TRY_COMPILE.rst b/Help/prop_gbl/IN_TRY_COMPILE.rst
index 3a2ef5b..fd2d2e1 100644
--- a/Help/prop_gbl/IN_TRY_COMPILE.rst
+++ b/Help/prop_gbl/IN_TRY_COMPILE.rst
@@ -3,4 +3,5 @@ IN_TRY_COMPILE
 
 Read-only property that is true during a try-compile configuration.
 
-True when building a project inside a TRY_COMPILE or TRY_RUN command.
+True when building a project inside a :command:`try_compile` or
+:command:`try_run` command.
diff --git a/Help/prop_gbl/PREDEFINED_TARGETS_FOLDER.rst 
b/Help/prop_gbl/PREDEFINED_TARGETS_FOLDER.rst
index e85b823..bf8c9a3 100644
--- a/Help/prop_gbl/PREDEFINED_TARGETS_FOLDER.rst
+++ b/Help/prop_gbl/PREDEFINED_TARGETS_FOLDER.rst
@@ -5,5 +5,5 @@ Name of FOLDER for targets that are added automatically by 
CMake.
 
 If not set, CMake uses "CMakePredefinedTargets" as a default value for
 this property.  Targets such as INSTALL, PACKAGE and RUN_TESTS will be
-organized into this FOLDER.  See also the documentation for the FOLDER
-target property.
+organized into this FOLDER.  See also the documentation for the
+:prop_tgt:`FOLDER` target property.
diff --git a/Help/prop_gbl/RULE_MESSAGES.rst

[Cmake-commits] CMake branch, next, updated. v3.5.2-1108-gb3f7515

2016-04-27 Thread Robert Maynard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  b3f751575385969e808fdaf45de09958822d5b1a (commit)
   via  21e2814ab5411d9f0e14e52fe12c7a3405cbee9b (commit)
  from  e4ce56bf57e165763dc206ff0b79d91d256548f1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b3f751575385969e808fdaf45de09958822d5b1a
commit b3f751575385969e808fdaf45de09958822d5b1a
Merge: e4ce56b 21e2814
Author: Robert Maynard 
AuthorDate: Wed Apr 27 16:36:16 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 16:36:16 2016 -0400

Merge topic 'intel-compiler-features' into next

21e2814a Features: Specify minimum Intel version to 12.1 for C and C++.


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=21e2814ab5411d9f0e14e52fe12c7a3405cbee9b
commit 21e2814ab5411d9f0e14e52fe12c7a3405cbee9b
Author: Robert Maynard 
AuthorDate: Wed Apr 27 15:28:33 2016 -0400
Commit: Robert Maynard 
CommitDate: Wed Apr 27 16:33:34 2016 -0400

Features: Specify minimum Intel version to 12.1 for C and C++.

Versions below 12.1 don't provide enough information to properly detect
if compiling with c++98 or c++0x enabled so remove them from the
supported list.

diff --git a/Modules/Compiler/Intel-C.cmake b/Modules/Compiler/Intel-C.cmake
index cfd7421..eb9602a 100644
--- a/Modules/Compiler/Intel-C.cmake
+++ b/Modules/Compiler/Intel-C.cmake
@@ -19,14 +19,14 @@ if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 15.0.0)
   set(CMAKE_C11_EXTENSION_COMPILE_OPTION "${_std}=c11")
 endif()
 
-if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 10.0)
+if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 12.1)
   set(CMAKE_C90_STANDARD_COMPILE_OPTION "${_std}=c89")
   set(CMAKE_C90_EXTENSION_COMPILE_OPTION "${_std}=c89")
   set(CMAKE_C99_STANDARD_COMPILE_OPTION "${_std}=c99")
   set(CMAKE_C99_EXTENSION_COMPILE_OPTION "${_std}=c99")
 endif()
 
-if(NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 10.0)
+if(NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 12.1)
   if (NOT CMAKE_C_COMPILER_FORCED)
 if (NOT CMAKE_C_STANDARD_COMPUTED_DEFAULT)
   message(FATAL_ERROR "CMAKE_C_STANDARD_COMPUTED_DEFAULT should be set for 
${CMAKE_C_COMPILER_ID} (${CMAKE_C_COMPILER}) version 
${CMAKE_C_COMPILER_VERSION}")
@@ -51,7 +51,7 @@ macro(cmake_record_c_compile_features)
 
   set(_result 0)
   if (NOT "x${CMAKE_C_SIMULATE_ID}" STREQUAL "xMSVC" AND
-  NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 10.0)
+  NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 12.1)
 if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 15.0.0)
   _get_intel_c_features(${CMAKE_C11_STANDARD_COMPILE_OPTION} 
CMAKE_C11_COMPILE_FEATURES)
 endif()
diff --git a/Modules/Compiler/Intel-CXX-FeatureTests.cmake 
b/Modules/Compiler/Intel-CXX-FeatureTests.cmake
index d328e3c..e111c07 100644
--- a/Modules/Compiler/Intel-CXX-FeatureTests.cmake
+++ b/Modules/Compiler/Intel-CXX-FeatureTests.cmake
@@ -12,7 +12,7 @@ endif()
 #set(_cmake_feature_test_cxx_variable_templates "${Intel15_CXX14}")
 #set(_cmake_feature_test_cxx_relaxed_constexpr "${Intel15_CXX14}")
 
-set(_cmake_oldestSupported "__INTEL_COMPILER >= 1110")
+set(_cmake_oldestSupported "__INTEL_COMPILER >= 1210")
 set(DETECT_CXX11 "((__cplusplus >= 201103L) || defined(__INTEL_CXX11_MODE__) 
|| defined(__GXX_EXPERIMENTAL_CXX0X__))")
 #ICC version 15 update 1 has a bug where __cplusplus is defined as 1 no matter
 #if you are compiling as 98/11/14. So to properly detect C++14 with this 
version
@@ -71,30 +71,26 @@ set(_cmake_feature_test_cxx_range_for "${Intel13_CXX11}")
 # Cannot find Intel documentation for N2640: cxx_uniform_initialization
 set(_cmake_feature_test_cxx_uniform_initialization "${Intel13_CXX11}")
 
-set(Intel121_CXX11 "__INTEL_COMPILER >= 1210 && ${DETECT_CXX11}")
+set(Intel121_CXX11 "${_cmake_oldestSupported} && ${DETECT_CXX11}")
 set(_cmake_feature_test_cxx_variadic_templates "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_alias_templates "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_nullptr "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_trailing_return_types "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_attributes "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_default_function_template_args "${Intel121_CXX11}")
-
-set(Intel12_CXX11 "__INTEL_COMPILER >= 1200 && ${DETECT_CXX11}")
-set(_cmake_feature_test_cxx_extended_friend_declarations "${Intel12_CXX11}")
-set(_cmake_feature_test_cxx_rvalue_references "${Intel12_CXX11}")
-set(_cmake_feature_test_cxx_decltype "${Intel12_CXX11}")
-set(_cmake_feature_test_cxx_defaulted_functions "${Intel12_CXX11}")
-set(_cmake_feature_test_cxx_deleted_functions "${Intel12_CXX11}")
-set(_cm

[Cmake-commits] CMake branch, next, updated. v3.5.2-1106-ge4ce56b

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  e4ce56bf57e165763dc206ff0b79d91d256548f1 (commit)
   via  edf1c8e37d96b6a657d83425b8a3977ff1fa54f5 (commit)
  from  60bb863b602c990788cc887f702b0b1cab87c6b8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e4ce56bf57e165763dc206ff0b79d91d256548f1
commit e4ce56bf57e165763dc206ff0b79d91d256548f1
Merge: 60bb863 edf1c8e
Author: Brad King 
AuthorDate: Wed Apr 27 14:34:57 2016 -0400
Commit: Brad King 
CommitDate: Wed Apr 27 14:34:57 2016 -0400

Merge branch 'master' into next


---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-518-gedf1c8e

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  edf1c8e37d96b6a657d83425b8a3977ff1fa54f5 (commit)
   via  1703a6d2c46cc7981dd80bd18d7c2e82ec5d9f82 (commit)
  from  3c934362096c5d4d74cb38ac2b1b085f5d471df4 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=edf1c8e37d96b6a657d83425b8a3977ff1fa54f5
commit edf1c8e37d96b6a657d83425b8a3977ff1fa54f5
Merge: 3c93436 1703a6d
Author: Brad King 
AuthorDate: Wed Apr 27 14:32:12 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 14:32:12 2016 -0400

Merge topic 'ghs-duplicate-objects'

1703a6d2 GHS: Fix handling of duplicate source filenames (#16046)


---

Summary of changes:
 Source/cmGhsMultiTargetGenerator.cxx   |   42 
 Source/cmGhsMultiTargetGenerator.h |2 +
 Tests/CMakeLists.txt   |   11 +
 .../CMakeLists.txt |   10 +
 Tests/GhsMultiDuplicateSourceFilenames/main.c  |9 +
 .../subfolder/test.c   |5 +++
 .../test.c}|3 +-
 7 files changed, 81 insertions(+), 1 deletion(-)
 create mode 100644 Tests/GhsMultiDuplicateSourceFilenames/CMakeLists.txt
 create mode 100644 Tests/GhsMultiDuplicateSourceFilenames/main.c
 create mode 100644 Tests/GhsMultiDuplicateSourceFilenames/subfolder/test.c
 copy Tests/{GhsMulti/ReturnNum/Lib/HelperFun.c => 
GhsMultiDuplicateSourceFilenames/test.c} (50%)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.5.2-1104-g60bb863

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  60bb863b602c990788cc887f702b0b1cab87c6b8 (commit)
   via  7db9f3f294126e5e02d172e54c83a8ac90ed23a3 (commit)
  from  5635d5b1221eba1faeee47556e067d40232fd7b8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=60bb863b602c990788cc887f702b0b1cab87c6b8
commit 60bb863b602c990788cc887f702b0b1cab87c6b8
Merge: 5635d5b 7db9f3f
Author: Brad King 
AuthorDate: Wed Apr 27 10:58:20 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 10:58:20 2016 -0400

Merge topic 'ExternalProject-git-clone-shallow' into next

7db9f3f2 ExternalProject: Add option to perform a shallow Git clone (#15291)


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7db9f3f294126e5e02d172e54c83a8ac90ed23a3
commit 7db9f3f294126e5e02d172e54c83a8ac90ed23a3
Author: Brad King 
AuthorDate: Wed Apr 27 08:47:32 2016 -0400
Commit: Brad King 
CommitDate: Wed Apr 27 10:58:07 2016 -0400

ExternalProject: Add option to perform a shallow Git clone (#15291)

Inspired-by: Ilya Kulakov 

diff --git a/Help/release/dev/ExternalProject-git-clone-shallow.rst 
b/Help/release/dev/ExternalProject-git-clone-shallow.rst
new file mode 100644
index 000..f06fe34
--- /dev/null
+++ b/Help/release/dev/ExternalProject-git-clone-shallow.rst
@@ -0,0 +1,5 @@
+ExternalProject-git-clone-shallow
+-
+
+* The :module:`ExternalProject` module leared the ``GIT_SHALLOW 1``
+  option to perform a shallow clone of a Git repository.
diff --git a/Modules/ExternalProject.cmake b/Modules/ExternalProject.cmake
index 1f3dc38..9cc8a20 100644
--- a/Modules/ExternalProject.cmake
+++ b/Modules/ExternalProject.cmake
@@ -61,6 +61,10 @@ Create custom targets to build projects in external trees
 The optional name of the remote, default to ``origin``
   ``GIT_SUBMODULES ...``
 Git submodules that shall be updated, all if empty
+  ``GIT_SHALLOW 1``
+Tell Git to clone with ``--depth 1``.   Use when ``GIT_TAG`` is not
+specified or when it names a branch in order to download only the
+tip of the branch without the rest of its history.
   ``HG_REPOSITORY ``
 URL of mercurial repo
   ``HG_TAG ``
@@ -499,7 +503,12 @@ define_property(DIRECTORY PROPERTY 
"EP_UPDATE_DISCONNECTED" INHERITED
   "ExternalProject module."
   )
 
-function(_ep_write_gitclone_script script_filename source_dir git_EXECUTABLE 
git_repository git_tag git_remote_name git_submodules src_name work_dir 
gitclone_infofile gitclone_stampfile tls_verify)
+function(_ep_write_gitclone_script script_filename source_dir git_EXECUTABLE 
git_repository git_tag git_remote_name git_submodules git_shallow src_name 
work_dir gitclone_infofile gitclone_stampfile tls_verify)
+  if(NOT GIT_VERSION_STRING VERSION_LESS 1.7.10)
+set(git_clone_shallow_options "--depth 1 --no-single-branch")
+  else()
+set(git_clone_shallow_options "--depth 1")
+  endif()
   file(WRITE ${script_filename}
 "if(\"${git_tag}\" STREQUAL \"\")
   message(FATAL_ERROR \"Tag for git checkout should not be empty.\")
@@ -533,12 +542,19 @@ if(NOT \"x${tls_verify}\" STREQUAL \"x\" AND NOT 
tls_verify)
 -c http.sslVerify=false)
 endif()
 
+set(git_clone_options)
+
+set(git_shallow \"${git_shallow}\")
+if(git_shallow)
+  list(APPEND git_clone_options ${git_clone_shallow_options})
+endif()
+
 # try the clone 3 times incase there is an odd git clone issue
 set(error_code 1)
 set(number_of_tries 0)
 while(error_code AND number_of_tries LESS 3)
   execute_process(
-COMMAND \"${git_EXECUTABLE}\" \${git_options} clone --origin 
\"${git_remote_name}\" \"${git_repository}\" \"${src_name}\"
+COMMAND \"${git_EXECUTABLE}\" \${git_options} clone \${git_clone_options} 
--origin \"${git_remote_name}\" \"${git_repository}\" \"${src_name}\"
 WORKING_DIRECTORY \"${work_dir}\"
 RESULT_VARIABLE error_code
 )
@@ -1793,6 +1809,7 @@ function(_ep_add_download_command name)
 if("x${tls_verify}" STREQUAL "x" AND DEFINED CMAKE_TLS_VERIFY)
   set(tls_verify "${CMAKE_TLS_VERIFY}")
 endif()
+get_property(git_shallow TARGET ${name} PROPERTY _EP_GIT_SHALLOW)
 
 # For the download step, and the git clone operation, only the repository
 # should be recorded in a configured RepositoryInfo file. If the repo
@@ -1817,7 +1834,7 @@ function(_ep_add_download_command name)
 # The script will delete the source directory and then call git clone.
 #
 _ep_write_gitclone_script(${tmp_dir}/${name}-gitclone.cmake ${source_dir}
-  ${GIT_EXECUTABLE} ${git_repository} ${git_tag} ${git_remote_name} 
"${git_submodules

[Cmake-commits] CMake branch, next, updated. v3.5.2-1102-g5635d5b

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  5635d5b1221eba1faeee47556e067d40232fd7b8 (commit)
   via  14e459662ba5513cdb8fb786f5345ae02f3cc6e6 (commit)
  from  cb2fab90674de77fb8fafdee90a3f1c266d75f05 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5635d5b1221eba1faeee47556e067d40232fd7b8
commit 5635d5b1221eba1faeee47556e067d40232fd7b8
Merge: cb2fab9 14e4596
Author: Brad King 
AuthorDate: Wed Apr 27 10:57:43 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 10:57:43 2016 -0400

Merge topic 'ExternalProject-git-clone-shallow' into next

14e45966 fixup! ExternalProject: Add option to perform a shallow Git clone 
(#15291)


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=14e459662ba5513cdb8fb786f5345ae02f3cc6e6
commit 14e459662ba5513cdb8fb786f5345ae02f3cc6e6
Author: Brad King 
AuthorDate: Wed Apr 27 10:43:37 2016 -0400
Commit: Brad King 
CommitDate: Wed Apr 27 10:43:37 2016 -0400

fixup! ExternalProject: Add option to perform a shallow Git clone (#15291)

diff --git a/Modules/ExternalProject.cmake b/Modules/ExternalProject.cmake
index 3198511..9cc8a20 100644
--- a/Modules/ExternalProject.cmake
+++ b/Modules/ExternalProject.cmake
@@ -62,8 +62,9 @@ Create custom targets to build projects in external trees
   ``GIT_SUBMODULES ...``
 Git submodules that shall be updated, all if empty
   ``GIT_SHALLOW 1``
-Tell Git to clone with ``--depth 1`` to download only the most
-recent commit of the repository and its submodules.
+Tell Git to clone with ``--depth 1``.   Use when ``GIT_TAG`` is not
+specified or when it names a branch in order to download only the
+tip of the branch without the rest of its history.
   ``HG_REPOSITORY ``
 URL of mercurial repo
   ``HG_TAG ``

---

Summary of changes:
 Modules/ExternalProject.cmake |5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.5.2-1100-gcb2fab9

2016-04-27 Thread Robert Maynard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  cb2fab90674de77fb8fafdee90a3f1c266d75f05 (commit)
   via  66e8b568dec347cc6202bd3a81526ee0491079df (commit)
  from  70948c3041c83aea59b15d873e5248cabe303bbe (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=cb2fab90674de77fb8fafdee90a3f1c266d75f05
commit cb2fab90674de77fb8fafdee90a3f1c266d75f05
Merge: 70948c3 66e8b56
Author: Robert Maynard 
AuthorDate: Wed Apr 27 10:12:50 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 10:12:50 2016 -0400

Merge topic 'intel-compiler-features' into next

66e8b568 Features: Update features for Intel 15 for lang C


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=66e8b568dec347cc6202bd3a81526ee0491079df
commit 66e8b568dec347cc6202bd3a81526ee0491079df
Author: Robert Maynard 
AuthorDate: Wed Apr 27 10:11:47 2016 -0400
Commit: Robert Maynard 
CommitDate: Wed Apr 27 10:11:47 2016 -0400

Features: Update features for Intel 15 for lang C

diff --git a/Modules/Compiler/Intel-C-FeatureTests.cmake 
b/Modules/Compiler/Intel-C-FeatureTests.cmake
index 5a0860f..34175c8 100644
--- a/Modules/Compiler/Intel-C-FeatureTests.cmake
+++ b/Modules/Compiler/Intel-C-FeatureTests.cmake
@@ -10,7 +10,8 @@ endif()
 
 set(DETECT_C99 "defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L")
 
-set(_cmake_feature_test_c_static_assert "__INTEL_COMPILER >= 1500 && 
${DETECT_C99}")
+#static assert is only around in version 1500 update 2 and above
+set(_cmake_feature_test_c_static_assert "(__INTEL_COMPILER > 1500 || 
(__INTEL_COMPILER == 1500 && __INTEL_COMPILER_UPDATE > 1) ) && ${DETECT_C99}")
 
 set(_cmake_oldestSupported "__INTEL_COMPILER >= 1110")
 set(Intel_C99 "${_cmake_oldestSupported} && ${DETECT_C99}")

---

Summary of changes:
 Modules/Compiler/Intel-C-FeatureTests.cmake |3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.5.2-1092-g5a97238

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  5a9723862ce1e27f75d4f6fb0ae91aab1b8a (commit)
   via  0209d23481bc5bfe0d7e4d40e0b8249083f9d50c (commit)
   via  b8a8dfec3688f1dc44f95528a65135fc76511c7b (commit)
  from  a7e7a045f88eaa2379e5b6126ce4e4b042739c92 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5a9723862ce1e27f75d4f6fb0ae91aab1b8a
commit 5a9723862ce1e27f75d4f6fb0ae91aab1b8a
Merge: a7e7a045 0209d23
Author: Brad King 
AuthorDate: Wed Apr 27 08:55:33 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 08:55:33 2016 -0400

Merge topic 'ExternalProject-git-clone-shallow' into next

0209d234 ExternalProject: Add option to perform a shallow Git clone (#15291)
b8a8dfec CMake Nightly Date Stamp


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0209d23481bc5bfe0d7e4d40e0b8249083f9d50c
commit 0209d23481bc5bfe0d7e4d40e0b8249083f9d50c
Author: Brad King 
AuthorDate: Wed Apr 27 08:47:32 2016 -0400
Commit: Brad King 
CommitDate: Wed Apr 27 08:54:37 2016 -0400

ExternalProject: Add option to perform a shallow Git clone (#15291)

Inspired-by: Ilya Kulakov 

diff --git a/Help/release/dev/ExternalProject-git-clone-shallow.rst 
b/Help/release/dev/ExternalProject-git-clone-shallow.rst
new file mode 100644
index 000..f06fe34
--- /dev/null
+++ b/Help/release/dev/ExternalProject-git-clone-shallow.rst
@@ -0,0 +1,5 @@
+ExternalProject-git-clone-shallow
+-
+
+* The :module:`ExternalProject` module leared the ``GIT_SHALLOW 1``
+  option to perform a shallow clone of a Git repository.
diff --git a/Modules/ExternalProject.cmake b/Modules/ExternalProject.cmake
index 1f3dc38..3198511 100644
--- a/Modules/ExternalProject.cmake
+++ b/Modules/ExternalProject.cmake
@@ -61,6 +61,9 @@ Create custom targets to build projects in external trees
 The optional name of the remote, default to ``origin``
   ``GIT_SUBMODULES ...``
 Git submodules that shall be updated, all if empty
+  ``GIT_SHALLOW 1``
+Tell Git to clone with ``--depth 1`` to download only the most
+recent commit of the repository and its submodules.
   ``HG_REPOSITORY ``
 URL of mercurial repo
   ``HG_TAG ``
@@ -499,7 +502,12 @@ define_property(DIRECTORY PROPERTY 
"EP_UPDATE_DISCONNECTED" INHERITED
   "ExternalProject module."
   )
 
-function(_ep_write_gitclone_script script_filename source_dir git_EXECUTABLE 
git_repository git_tag git_remote_name git_submodules src_name work_dir 
gitclone_infofile gitclone_stampfile tls_verify)
+function(_ep_write_gitclone_script script_filename source_dir git_EXECUTABLE 
git_repository git_tag git_remote_name git_submodules git_shallow src_name 
work_dir gitclone_infofile gitclone_stampfile tls_verify)
+  if(NOT GIT_VERSION_STRING VERSION_LESS 1.7.10)
+set(git_clone_shallow_options "--depth 1 --no-single-branch")
+  else()
+set(git_clone_shallow_options "--depth 1")
+  endif()
   file(WRITE ${script_filename}
 "if(\"${git_tag}\" STREQUAL \"\")
   message(FATAL_ERROR \"Tag for git checkout should not be empty.\")
@@ -533,12 +541,19 @@ if(NOT \"x${tls_verify}\" STREQUAL \"x\" AND NOT 
tls_verify)
 -c http.sslVerify=false)
 endif()
 
+set(git_clone_options)
+
+set(git_shallow \"${git_shallow}\")
+if(git_shallow)
+  list(APPEND git_clone_options ${git_clone_shallow_options})
+endif()
+
 # try the clone 3 times incase there is an odd git clone issue
 set(error_code 1)
 set(number_of_tries 0)
 while(error_code AND number_of_tries LESS 3)
   execute_process(
-COMMAND \"${git_EXECUTABLE}\" \${git_options} clone --origin 
\"${git_remote_name}\" \"${git_repository}\" \"${src_name}\"
+COMMAND \"${git_EXECUTABLE}\" \${git_options} clone \${git_clone_options} 
--origin \"${git_remote_name}\" \"${git_repository}\" \"${src_name}\"
 WORKING_DIRECTORY \"${work_dir}\"
 RESULT_VARIABLE error_code
 )
@@ -1793,6 +1808,7 @@ function(_ep_add_download_command name)
 if("x${tls_verify}" STREQUAL "x" AND DEFINED CMAKE_TLS_VERIFY)
   set(tls_verify "${CMAKE_TLS_VERIFY}")
 endif()
+get_property(git_shallow TARGET ${name} PROPERTY _EP_GIT_SHALLOW)
 
 # For the download step, and the git clone operation, only the repository
 # should be recorded in a configured RepositoryInfo file. If the repo
@@ -1817,7 +1833,7 @@ function(_ep_add_download_command name)
 # The script will delete the source directory and then call git clone.
 #
 _ep_write_gitclone_script(${tmp_dir}/${name}-gitclone.cmake ${source_dir}
-  ${GIT_EXECUTABLE} ${git_repository} ${git_tag} ${git_remote
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.5.2-1098-g70948c3

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  70948c3041c83aea59b15d873e5248cabe303bbe (commit)
   via  3c934362096c5d4d74cb38ac2b1b085f5d471df4 (commit)
   via  8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1 (commit)
   via  a594b79b3cd7541ecfbcaaf7247049b172c15f41 (commit)
  from  690bc37cd987b3e05078cd3c40a38eb79225b2a4 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=70948c3041c83aea59b15d873e5248cabe303bbe
commit 70948c3041c83aea59b15d873e5248cabe303bbe
Merge: 690bc37 3c93436
Author: Brad King 
AuthorDate: Wed Apr 27 09:15:37 2016 -0400
Commit: Brad King 
CommitDate: Wed Apr 27 09:15:37 2016 -0400

Merge branch 'master' into next


---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-516-g3c93436

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  3c934362096c5d4d74cb38ac2b1b085f5d471df4 (commit)
   via  9647af3f4c7f6bd1a98e51c449db0fd98f353beb (commit)
   via  9b58190c8fb1e48ce02480f6a71f561f45299379 (commit)
  from  8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3c934362096c5d4d74cb38ac2b1b085f5d471df4
commit 3c934362096c5d4d74cb38ac2b1b085f5d471df4
Merge: 8a00c16 9647af3
Author: Brad King 
AuthorDate: Wed Apr 27 09:15:22 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 09:15:22 2016 -0400

Merge topic 'autogen-message-cleanup'

9647af3f Autogen: Message tweaks: Compiler type (moc/qrc/ui) added to 
progress messages
9b58190c Autogen: Message cleanups: Compose messages in std::stringstream


---

Summary of changes:
 Source/cmQtAutoGeneratorInitializer.cxx |   12 +-
 Source/cmQtAutoGenerators.cxx   |  270 ++-
 Source/cmQtAutoGenerators.h |5 +-
 3 files changed, 174 insertions(+), 113 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-513-g8a00c16

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1 (commit)
   via  571bedec2970df42b9f3666e17728a7511d32b47 (commit)
   via  0c58d2d0fdc518e12e6aa5a15012437c573a910c (commit)
  from  a594b79b3cd7541ecfbcaaf7247049b172c15f41 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1
commit 8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1
Merge: a594b79 571bede
Author: Brad King 
AuthorDate: Wed Apr 27 09:15:20 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 09:15:20 2016 -0400

Merge topic 'vs-old-express-no-folders'

571bedec VS: Ignore USE_FOLDER property on VS versions that do not support 
it
0c58d2d0 VS: Detect VS 8 and 9 Express editions


---

Summary of changes:
 Source/cmGlobalVisualStudio10Generator.cxx |6 --
 Source/cmGlobalVisualStudio10Generator.h   |6 --
 Source/cmGlobalVisualStudio11Generator.cxx |8 
 Source/cmGlobalVisualStudio71Generator.h   |3 +++
 Source/cmGlobalVisualStudio8Generator.cxx  |   10 ++
 Source/cmGlobalVisualStudio8Generator.h|6 ++
 Source/cmGlobalVisualStudio9Generator.cxx  |4 
 Source/cmGlobalVisualStudioGenerator.cxx   |2 +-
 8 files changed, 28 insertions(+), 17 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.5.2-1094-g690bc37

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  690bc37cd987b3e05078cd3c40a38eb79225b2a4 (commit)
   via  04d74a7f891dc01b2a9c6b1388f303af9404c49b (commit)
  from  5a9723862ce1e27f75d4f6fb0ae91aab1b8a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=690bc37cd987b3e05078cd3c40a38eb79225b2a4
commit 690bc37cd987b3e05078cd3c40a38eb79225b2a4
Merge: 5a97238 04d74a7
Author: Brad King 
AuthorDate: Wed Apr 27 09:10:07 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 09:10:07 2016 -0400

Merge topic 'clang-tidy-output-cleanup' into next

04d74a7f Clang-Tidy: copy stdout to sterr; ignore original stderr


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=04d74a7f891dc01b2a9c6b1388f303af9404c49b
commit 04d74a7f891dc01b2a9c6b1388f303af9404c49b
Author: Daniel Pfeifer 
AuthorDate: Tue Apr 26 22:50:54 2016 +0200
Commit: Brad King 
CommitDate: Wed Apr 27 09:06:47 2016 -0400

Clang-Tidy: copy stdout to sterr; ignore original stderr

Clang-Tidy writes the number of warnings, the number of suppressed
warnings, and instructions on how to suppress warnings to stderr.  Since
each source file is checked individually, this repetitive information is
disturbing and should be suppressed.

The actual warning messages are written to stdout.  Some IDEs (eg.
QtCreator) analyze only stderr for issues.  Redirecting Clang-Tidy's
stdout to stderr makes sure the warnings are correctly displayed.

diff --git a/Source/cmcmd.cxx b/Source/cmcmd.cxx
index 3c28c35..0b9518c 100644
--- a/Source/cmcmd.cxx
+++ b/Source/cmcmd.cxx
@@ -389,13 +389,17 @@ int cmcmd::ExecuteCMakeCommand(std::vector& 
args)
 tidy_cmd.push_back("--");
 tidy_cmd.insert(tidy_cmd.end(), orig_cmd.begin()+1, orig_cmd.end());
 
-// Run the tidy command line.
-if(!cmSystemTools::RunSingleCommand(tidy_cmd, 0, 0, &ret, 0,
-cmSystemTools::OUTPUT_PASSTHROUGH))
+// Run the tidy command line.  Capture its stdout and hide its stderr.
+std::string stdOut;
+if(!cmSystemTools::RunSingleCommand(tidy_cmd, &stdOut, 0, &ret, 0,
+cmSystemTools::OUTPUT_NONE))
   {
   std::cerr << "Error running '" << tidy_cmd[0] << "'\n";
   return 1;
   }
+
+// Output the stdout from clang-tidy to stderr
+std::cerr << stdOut;
 }
 
   // Now run the real compiler command and return its result value.

---

Summary of changes:
 Source/cmcmd.cxx |   10 +++---
 1 file changed, 7 insertions(+), 3 deletions(-)


hooks/post-receive